@@ -6,13 +6,19 @@
 #' @param map optional RgoogleMaps map object
 #' @param cex character expansion
 #' @param lwd line width of individual circles
-#' @description Draws a bullseye with concentric circles of black and white.
+#' @description Draws a bullseye with concentric circles of black and white at the specified location.
 #' @examples
 #' wa <- monitor_subset(Northwest_Megafires, stateCodes='WA', tlim=c(20150821,20150828))
 #' monitor_map(wa, cex=4)
 #' addBullseye(wa$meta$longitude, wa$meta$latitude)
 
-addBullseye <- function(longitude, latitude, map=NULL, cex=2.0, lwd=2) {
+addBullseye <- function(
+  longitude,
+  latitude,
+  map = NULL,
+  cex = 2.0,
+  lwd = 2
+) {
 
   if ( !is.null(map) ) {
     # RgoogleMap
