@@ -32,8 +32,13 @@
 #' @references \href{http://usfs.airsis.com}{Interagency Real Time Smoke Monitoring}
 #' @examples
 #' \dontrun{
+#' # Fail gracefully if any resources are not available
+#' try({
+#'
 #' fileString <- airsis_downloadData( 20150701, 20151231, provider='USFS', unitID='1026')
 #' monitorTypeList <- airsis_identifyMonitorType(fileString)
+#'
+#' }, silent = FALSE)
 #' }
 
 airsis_identifyMonitorType <- function(df) {
@@ -42,9 +47,16 @@ airsis_identifyMonitorType <- function(df) {
 
   # ----- Different header styles ----------------------------------------------
 
-  # USFS_esamMulti, provider = "usfs", unitID=1072-5 (starting in June, 2020)
-                   ###"MasterTable_ID,Alias,Latitude,Longitude,Conc(mg/m3),Flow(l/m),AT(C),BP(PA),RHx(%),RHi(%),WS(M/S),WD(Deg),BV(V),Alarm,Oceaneering Unit Voltage,TimeStamp,PDate"
-  esamMulti_header <- "MasterTable_ID,Alias,Latitude,Longitude,Conc(ug/m3),Flow(l/m),AT(C),BP(PA),RHx(%),RHi(%),WS(M/S),WD(Deg),BV(V),Alarm,Oceaneering Unit Voltage,TimeStamp,PDate"
+  # ebamMulti2_B, provider = "usfs", unitID = 1085 (starting in October, 2021)
+  ebamMulti2_B_header <- "MasterTable_ID,Alias,Latitude,Longitude,Date/Time/GMT,ConcRT,ConcHR,ConcS(mg/m3),Flow,W/S,W/D,AT,RHx,BP(mmHg),RHi,Oceaneering Unit Voltage,FT,Status,Type,BV,TimeStamp,PDate"
+  ebamMulti2_B_rawNames <- unlist(stringr::str_split(ebamMulti2_B_header, ','))
+  ebamMulti2_B_names <- make.names(ebamMulti2_B_rawNames)
+  # "74011903,1085 Three Rivers,,,9/29/2021 3:00:00 PM,0.002,0.0041,0.0041,16.67,0.0,0,22.2,50,749.9,29,,26.3,Normal,PM 2.5,0,9/29/2021 3:05:14 PM,9/29/2021 3:06:00 PM"
+  ebamMulti2_B_types <- 'ccddcddddddddddddccdc'
+
+
+  # USFS_esamMulti, provider = "usfs", unitID=1072-5 (starting in July 08, 2020; was mistakenly in units of ug/m3 before that)
+  esamMulti_header <- "MasterTable_ID,Alias,Latitude,Longitude,Conc(mg/m3),Flow(l/m),AT(C),BP(PA),RHx(%),RHi(%),WS(M/S),WD(Deg),BV(V),Alarm,Oceaneering Unit Voltage,TimeStamp,PDate"
   esamMulti_rawNames <- unlist(stringr::str_split(esamMulti_header, ','))
   esamMulti_names <- make.names(esamMulti_rawNames)
   # "64424513,USFS 1072,,,2,2.0,33.3,86107,1,13,2.6,175,14,,,6/14/2020 12:05:13 AM,6/14/2020 12:05:00 AM"
@@ -174,7 +186,15 @@ airsis_identifyMonitorType <- function(df) {
     rawNames <- unitid_bam1020_rawNames
     columnNames <- unitid_bam1020_names
     columnTypes <- unitid_bam1020_types
+
   # NOTE:  Now check for the older, pre-unitid headers in the same order
+
+  } else if ( dplyr::setequal(ebamMulti2_B_names, colNames) ) {
+    monitorType <- "EBAM"
+    monitorSubtype <- "MULTI2_B"
+    rawNames <- ebamMulti2_B_rawNames
+    columnNames <- ebamMulti2_B_names
+    columnTypes <- ebamMulti2_B_types
   } else if ( dplyr::setequal(esamMulti_names, colNames) ) {
     monitorType <- "ESAM"
     monitorSubtype <- "MULTI"
