@@ -26,7 +26,7 @@
 #' \item{\code{remove_Lat_zero = TRUE}}
 #' \item{\code{valid_Flow = c(16.7*0.95,16.7*1.05)}}
 #' \item{\code{valid_AT = c(-Inf,45)}}
-#' \item{\code{valid_RHi = c(-Inf,45)}}
+#' \item{\code{valid_RHi = c(-Inf,50)}}
 #' \item{\code{valid_Conc = c(-Inf,5.000)}}
 #' }
 #'
@@ -89,6 +89,8 @@ airsis_qualityControl <- function(
 
     if ( monitorSubtype == "MULTI2" ) {
       tbl <- airsis_EBAM_MULTI2QualityControl(tbl, ...)
+    } else if ( monitorSubtype == "MULTI2_B" ) {
+      tbl <- airsis_EBAM_MULTI2_BQualityControl(tbl, ...)
     } else if ( monitorSubtype == "PLUS_MULTI" ) {
       tbl <- airsis_EBAM_PLUS_MULTIQualityControl(tbl, ...)
     } else {
