@@ -21,45 +21,54 @@
 #'                       timezone='America/Los_Angeles')
 #' Methow_Valley <- monitor_join(Jul, Aug, monitorIDs=c('530470010_01','530470009_01'))
 #' }
-monitor_join <- function(ws_monitor1 = NULL,
-                         ws_monitor2 = NULL,
-                         monitorIDs = NULL) {
+monitor_join <- function(
+  ws_monitor1 = NULL,
+  ws_monitor2 = NULL,
+  monitorIDs = NULL
+) {
+
+  # ----- Validate parameters --------------------------------------------------
+
+  if ( !"ws_monitor" %in% class(ws_monitor1) )
+    stop("Required argument 'ws_monitor1' is not a ws_monitor object")
+
+  if ( !"ws_monitor" %in% class(ws_monitor2) )
+    stop("Required argument 'ws_monitor2' is not a ws_monitor object")
 
-  # Sanity checks
-  if ( !"ws_monitor" %in% class(ws_monitor1) ) stop("Required argument 'ws_monitor1' is not a ws_monitor object")
-  if ( !"ws_monitor" %in% class(ws_monitor2) ) stop("Required argument 'ws_monitor2' is not a ws_monitor object")
   if ( is.null(monitorIDs) ) {
     monitorIDs <- intersect(ws_monitor1$meta$monitorID, ws_monitor2$meta$monitorID)
   }
 
+  # ----- Create monitor list --------------------------------------------------
+
   # Create an overall time axis
   starttime <- min(ws_monitor1$data$datetime, ws_monitor2$data$datetime)
   endtime <- max(ws_monitor1$data$datetime, ws_monitor2$data$datetime)
-  datetime <- seq(starttime, endtime, by="hours")
-  hourlyDF <- data.frame(datetime=datetime)
+  datetime <- seq(starttime, endtime, by = "hours")
+  hourlyDF <- data.frame(datetime = datetime)
 
   monList <- list()
   for ( monitorID in monitorIDs ) {
 
     # Get trimmed, single version of mon1
-    mon1 <- monitor_subset(ws_monitor1, monitorIDs=monitorID)
+    mon1 <- monitor_subset(ws_monitor1, monitorIDs = monitorID)
     if ( monitor_isEmpty(mon1) ) {
       data1 <- hourlyDF
       data1[[monitorID]] <- NA
     } else {
       mon1 <- monitor_trim(mon1)
-      data1 <- dplyr::full_join(hourlyDF, mon1$data, by="datetime")
+      data1 <- dplyr::full_join(hourlyDF, mon1$data, by = "datetime")
     }
     mask1 <- !is.na(data1[[monitorID]])
 
     # Get trimmed, single version of mon2
-    mon2 <- monitor_subset(ws_monitor2, monitorIDs=monitorID)
+    mon2 <- monitor_subset(ws_monitor2, monitorIDs = monitorID)
     if ( monitor_isEmpty(mon2) ) {
       data2 <- hourlyDF
       data2[[monitorID]] <- NA
     } else {
       mon2 <- monitor_trim(mon2)
-      data2 <- dplyr::full_join(hourlyDF, mon2$data, by="datetime")
+      data2 <- dplyr::full_join(hourlyDF, mon2$data, by = "datetime")
     }
     mask2 <- !is.na(data2[[monitorID]])
 
@@ -78,10 +87,10 @@ monitor_join <- function(ws_monitor1 = NULL,
 
     # Create a valid monitor object if possible
     if ( !monitor_isEmpty(mon1) ) {
-      mon <- list(meta=mon1$meta, data=joinedData)
+      mon <- list(meta = mon1$meta, data = joinedData)
       monList[[monitorID]] <- structure(mon, class = c("ws_monitor", "list"))
     } else if ( !monitor_isEmpty(mon2) ) {
-      mon <- list(meta=mon2$meta, data=joinedData)
+      mon <- list(meta = mon2$meta, data = joinedData)
       monList[[monitorID]] <- structure(mon, class = c("ws_monitor", "list"))
     } else {
       # Bad monitor ID. Do nothing.
@@ -89,6 +98,8 @@ monitor_join <- function(ws_monitor1 = NULL,
 
   }
 
+  # ----- Return ---------------------------------------------------------------
+
   ws_monitor <- monitor_combine(monList)
 
   return(ws_monitor)
