@@ -62,20 +62,22 @@
 #'                            monitorIDs = c("410190002_01"))
 #' monitor_rollingMeanPlot(Roseburg, shadedNight = TRUE)
 
-monitor_rollingMeanPlot <- function(ws_monitor,
-                                    monitorID = NULL,
-                                    width = 3,
-                                    align = "center",
-                                    data.thresh = 75,
-                                    tlim = NULL,
-                                    ylim = NULL,
-                                    localTime = TRUE,
-                                    shadedNight = FALSE,
-                                    aqiLines = TRUE,
-                                    gridHorizontal = FALSE,
-                                    grid24hr = FALSE,
-                                    grid3hr = FALSE,
-                                    showLegend = TRUE) {
+monitor_rollingMeanPlot <- function(
+  ws_monitor,
+  monitorID = NULL,
+  width = 3,
+  align = "center",
+  data.thresh = 75,
+  tlim = NULL,
+  ylim = NULL,
+  localTime = TRUE,
+  shadedNight = FALSE,
+  aqiLines = TRUE,
+  gridHorizontal = FALSE,
+  grid24hr = FALSE,
+  grid3hr = FALSE,
+  showLegend = TRUE
+) {
 
   # Sanity check
   if ( monitor_isEmpty(ws_monitor) ) {
