@@ -12,20 +12,27 @@
 #' @seealso \link{skill_ROC}
 #' @examples
 #' \dontrun{
+#' # Fail gracefully if any resources are not available
+#' try({
+#'
 #' # Napa Fires -- October, 2017
 #' ca <- airnow_loadAnnual(2017) %>%
 #'   monitor_subset(tlim = c(20171001,20171101), stateCodes = 'CA')
 #' Vallejo <- monitor_subset(ca, monitorIDs = '060950004_01')
 #' Napa <- monitor_subset(ca, monitorIDs = '060550003_01')
 #' skill_ROCPlot(Vallejo, Napa)
+#'
+#' }, silent = FALSE)
 #' }
 
-skill_ROCPlot <- function(predicted,
-                          observed,
-                          t1Range = c(0,100),
-                          t2s = seq(10,100,10),
-                          n = 101,
-                          colors = grDevices::rainbow(length(t2s))) {
+skill_ROCPlot <- function(
+  predicted,
+  observed,
+  t1Range = c(0,100),
+  t2s = seq(10,100,10),
+  n = 101,
+  colors = grDevices::rainbow(length(t2s))
+) {
 
   # Extract data from ws_monitor objects
   if ( 'ws_monitor' %in% class(predicted) ) {
