@@ -43,7 +43,7 @@
 #' }
 #'
 #' Available WRCC RData and associated log files can be seen at:
-#' \href{https://haze.airfire.org/monitoring/WRCC/RData}{https://haze.airfire.org/monitoring/WRCC/RData}
+#' \href{https://haze.airfire.org/monitoring/WRCC/RData/}{https://haze.airfire.org/monitoring/WRCC/RData/}
 #' @seealso \code{\link{wrcc_loadDaily}}
 #' @seealso \code{\link{wrcc_loadLatest}}
 #'
@@ -58,6 +58,9 @@
 #'
 #' @examples
 #' \dontrun{
+#' # Fail gracefully if any resources are not available
+#' try({
+#'
 #' wrcc_loadAnnual(2017) %>%
 #'   monitor_subset(stateCodes='MT', tlim=c(20170701,20170930)) %>%
 #'   monitor_dailyStatistic() %>%
@@ -65,14 +68,18 @@
 #'   addAQIStackedBar()
 #'   addAQILines()
 #'   title("Montana 2017 -- WRCC Daily Average PM2.5")
+#'
+#' }, silent = FALSE)
 #' }
 
-wrcc_loadAnnual <- function(year = NULL,
-                            parameter = 'PM2.5',
-                            baseUrl = 'https://haze.airfire.org/monitoring',
-                            dataDir = NULL) {
+wrcc_loadAnnual <- function(
+  year = NULL,
+  parameter = 'PM2.5',
+  baseUrl = 'https://haze.airfire.org/monitoring',
+  dataDir = NULL
+) {
 
-  # Validate parameters --------------------------------------------------------
+  # ----- Validate parameters --------------------------------------------------
 
   if ( is.null(year) ) {
     stop("Required parameter 'year' is missing.")
