@@ -4,7 +4,7 @@ test_that("arguments are validated", {
   # Set up for "Thompson Falls, Montana"
   startdate <- lubridate::ymd_hms("2018-11-03 07:00:00")
   enddate <- lubridate::ymd_hms("2018-11-06 07:00:00")
-  datetime <- seq(startdate, enddate, by="hours")
+  datetime <- seq(startdate, enddate, by = "hours")
   longitude <- -115.3237
   latitude <- 47.59439
   timezone <- "America/Denver"
@@ -15,15 +15,13 @@ test_that("arguments are validated", {
   expect_error( timeInfo(datetime, longitude) )
   expect_error( timeInfo(datetime, longitude, "dummy") )
 
-  # Should determine timezone from datetime if no timezone is provided
-  expect_silent( timeInfo <- timeInfo(datetime, longitude, latitude) )
 })
 
 test_that("daylight savings is treated properly", {
   # Set up for "Thompson Falls, Montana"
   startdate <- lubridate::ymd_hms("2018-11-03 07:00:00")
   enddate <- lubridate::ymd_hms("2018-11-06 07:00:00")
-  datetime <- seq(startdate, enddate, by="hours")
+  datetime <- seq(startdate, enddate, by = "hours")
   longitude <- -115.3237
   latitude <- 47.59439
   timezone <- "America/Denver"
@@ -72,7 +70,7 @@ test_that("non-Olsen timezones are handled", {
   # Set up for "Portland, Oregon"
   startdate <- lubridate::ymd_hms("2019-06-15 07:00:00")
   enddate <- lubridate::ymd_hms("2019-06-16 06:00:00")
-  datetime <- seq(startdate, enddate, by="hours")
+  datetime <- seq(startdate, enddate, by = "hours")
 
   # Portland, Oregon
   expect_error( timeInfo(datetime, -122.6, 45.5, "US/Pacific"), NA ) # no error
@@ -82,7 +80,7 @@ test_that("ocean locations require timezones", {
   # Set up for "Portland, Oregon"
   startdate <- lubridate::ymd_hms("2019-06-15 07:00:00")
   enddate <- lubridate::ymd_hms("2019-06-16 06:00:00")
-  datetime <- seq(startdate, enddate, by="hours")
+  datetime <- seq(startdate, enddate, by = "hours")
 
   # Far from land in the Southern Pacific
   expect_error( timeInfo(datetime, -160, -40), NULL ) # error
